@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1788 2026/02/09 08:09:46 sebastia Exp $
+# $OpenBSD: Quirks.pm,v 1.1789 2026/02/11 23:23:05 bentley Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -511,6 +511,8 @@ my $stem_extensions = {
 	'ruby34-hiera-file' => 'hiera-file',
 	'ruby34-puppet-lint' => 'puppet-lint',
 	'ruby34-r10k' => 'r10k',
+	'adobe-source-sans-pro' => 'adobe-source-sans',
+	'adobe-source-serif-pro' => 'adobe-source-serif',
 };
 
 my $obsolete_reason = {};
